@@ -5,8 +5,7 @@ class CellAutomatRegression:
                 data:pd.DataFrame, 
                 name_item = None, 
                 name_user = None,
-                number_items:int = None,
-                number_users:int = None,
+                number_output:int = None,
                 num_layers:int = 1, 
                 method:str = "moore",
                 round: int = 1):
@@ -17,8 +16,7 @@ class CellAutomatRegression:
             name_user (optional): User name(First name, Second name, number name, etc.). Defaults to None.
             num_layers (int, optional): Number of counting environment layers. Defaults to 1.
             method (str, optional): Method counting environment ["moore", "neumann"]. Defaults to "moore".
-            number_items (int, optional): Count return items. Only for "number_item"==None. Defaults to 5.
-            number_users (int, optional): Count return users. Only for "number item"==None. Defaults to 5.
+            number_output (int, optional): Count return items. Only for "name_item"==None or "name_ures"==None. Defaults to 5.
             round (int, optional): Up to how many decimal places to round the score. Default to 1]
         """
         self.data = data
@@ -26,8 +24,7 @@ class CellAutomatRegression:
         self.name_user = name_user
         self.num_layers = num_layers
         self.method = method
-        self.number_items = number_items
-        self.number_users = number_users
+        self.number_output = number_output
         self.round = round
         
     def create_user_corr(self, name_user)->pd.DataFrame:
@@ -79,9 +76,9 @@ class CellAutomatRegression:
         Returns:
             pd.DataFrame: Intermediate dataframe
         """
-        data.insert(self.num_layers+1, name_item, value=data.iloc[:, 0].values, allow_duplicates=True)
+        df = data.copy()
+        df.insert(self.num_layers+1, name_item, value=data.iloc[:, 0].values, allow_duplicates=True)
         data_new = data.iloc[:, 1:]
-        data = data.T.drop_duplicates().T
         data_transp = data_new.T
         data_transp.insert(self.num_layers+1, name_user, value=data_transp.iloc[:, 0].values, allow_duplicates=True)
         data_transp = data_transp.iloc[:, 1:]
@@ -120,18 +117,14 @@ class CellAutomatRegression:
         condition = [self.num_layers > min(self.data.shape[0]//2, self.data.shape[1]//2) or self.num_layers <= 0, 
                     self.name_item != None and self.name_user != None and self.data.loc[self.name_user, self.name_item] != 0.0, 
                     self.method not in methods,
-                    self.number_items != None and self.number_items > self.data.shape[1], 
-                    self.number_users != None and self.number_users > self.data.shape[0],
-                    self.number_items != None and self.number_items <= 0,
-                    self.number_users != None and self.number_users <= 0,
+                    (self.number_output != None and self.number_output > self.data.shape[1] and self.name_item == None) or ((self.number_output != None and self.number_output > self.data.shape[0] and self.name_user == None)), 
+                    self.number_output != None and self.number_output <= 0,
                     self.round < 0]
         label = ["Too many layers of counting or num_layers <= 0", 
                 f"Your item {self.name_item} is already rated by user {self.name_user}", 
                 f"Not found method {self.method}, try one of the available - {methods}", 
-                "Parameter 'number_items' is so large",
-                "Parameter 'number_users' is so large", 
-                "Parametrt number_items must be [1, data.shape[1]",
-                "Parametrt number_users must be [1, data.shape[0]",
+                "Parameter 'number_output' is so large",
+                "Parametrt number_output must be [1, data.shape[1]] or [1, data.shape[0]]",
                 "Parameter round must be >= 0"]
         output = np.select(condition, label)
         if output != "0":
@@ -167,14 +160,14 @@ class CellAutomatRegression:
                 main_score = self.count_score(sample_data = sample_data)
                 if main_score != 0.0:
                     scores[item] = main_score
-            if self.number_items == None:
+            if self.number_output == None:
                 print(f"Done. Prediction for user {self.name_user} to return dict item_name -> score")
                 return scores
             else:
                 print(f"Done. Prediction for user {self.name_user} to return dict item_name -> score")
                 score_tuples = sorted(scores.items(), key=lambda item: item[1], reverse=True)
-                if self.number_items <= len(score_tuples):
-                    sorted_score = {k: v for k, v in score_tuples[:self.number_items]}
+                if self.number_output <= len(score_tuples):
+                    sorted_score = {k: v for k, v in score_tuples[:self.number_output]}
                 else:
                     sorted_score = {k: v for k, v in score_tuples}
                 return sorted_score 
@@ -193,14 +186,14 @@ class CellAutomatRegression:
                 main_score = self.count_score(sample_data = sample_data)
                 if main_score != 0.0:
                     scores[user] = main_score
-            if self.number_users == None:
+            if self.number_output == None:
                 print(f"Done. Prediction for item {self.name_item} to return dict user_name -> score")
                 return scores
             else:
                 print(f"Done. Prediction for item {self.name_item} to return dict user_name -> score")
                 score_tuples = sorted(scores.items(), key=lambda item: item[1], reverse=True)
-                if self.number_users <= len(score_tuples):
-                    sorted_score = {k: v for k, v in score_tuples[:self.number_users]}
+                if self.number_output <= len(score_tuples):
+                    sorted_score = {k: v for k, v in score_tuples[:self.number_output]}
                 else:
                     sorted_score = {k: v for k, v in score_tuples}
                 return sorted_score 
\ No newline at end of file
